@@ -64,7 +64,7 @@ class Exceptions:
 
 class QLDBClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html)
     """
 
@@ -80,7 +80,7 @@ class QLDBClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#can_paginate)
         """
 
@@ -90,7 +90,7 @@ class QLDBClient(BaseClient):
         """
         Ends a given Amazon QLDB journal stream.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.cancel_journal_kinesis_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.cancel_journal_kinesis_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#cancel_journal_kinesis_stream)
         """
 
@@ -99,14 +99,14 @@ class QLDBClient(BaseClient):
         *,
         Name: str,
         PermissionsMode: PermissionsModeType,
-        Tags: Mapping[str, str] = None,
-        DeletionProtection: bool = None,
-        KmsKey: str = None
+        Tags: Mapping[str, str] = ...,
+        DeletionProtection: bool = ...,
+        KmsKey: str = ...
     ) -> CreateLedgerResponseTypeDef:
         """
         Creates a new ledger in your account in the current Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.create_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.create_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#create_ledger)
         """
 
@@ -114,7 +114,7 @@ class QLDBClient(BaseClient):
         """
         Deletes a ledger and all of its contents.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.delete_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.delete_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#delete_ledger)
         """
 
@@ -124,7 +124,7 @@ class QLDBClient(BaseClient):
         """
         Returns detailed information about a given Amazon QLDB journal stream.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.describe_journal_kinesis_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.describe_journal_kinesis_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#describe_journal_kinesis_stream)
         """
 
@@ -136,7 +136,7 @@ class QLDBClient(BaseClient):
         export ID, creation time, current status, and the parameters of the original
         export creation request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.describe_journal_s3_export)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.describe_journal_s3_export)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#describe_journal_s3_export)
         """
 
@@ -145,7 +145,7 @@ class QLDBClient(BaseClient):
         Returns information about a ledger, including its state, permissions mode,
         encryption at rest settings, and when it was created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.describe_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.describe_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#describe_ledger)
         """
 
@@ -162,21 +162,21 @@ class QLDBClient(BaseClient):
         Exports journal contents within a date and time range from a ledger into a
         specified Amazon Simple Storage Service (Amazon S3) bucket.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.export_journal_to_s3)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.export_journal_to_s3)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#export_journal_to_s3)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#generate_presigned_url)
         """
 
@@ -185,12 +185,12 @@ class QLDBClient(BaseClient):
         *,
         Name: str,
         BlockAddress: "ValueHolderTypeDef",
-        DigestTipAddress: "ValueHolderTypeDef" = None
+        DigestTipAddress: "ValueHolderTypeDef" = ...
     ) -> GetBlockResponseTypeDef:
         """
         Returns a block object at a specified address in a journal.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.get_block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.get_block)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#get_block)
         """
 
@@ -198,7 +198,7 @@ class QLDBClient(BaseClient):
         """
         Returns the digest of a ledger at the latest committed block in the journal.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.get_digest)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.get_digest)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#get_digest)
         """
 
@@ -208,55 +208,55 @@ class QLDBClient(BaseClient):
         Name: str,
         BlockAddress: "ValueHolderTypeDef",
         DocumentId: str,
-        DigestTipAddress: "ValueHolderTypeDef" = None
+        DigestTipAddress: "ValueHolderTypeDef" = ...
     ) -> GetRevisionResponseTypeDef:
         """
         Returns a revision data object for a specified document ID and block address.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.get_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.get_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#get_revision)
         """
 
     def list_journal_kinesis_streams_for_ledger(
-        self, *, LedgerName: str, MaxResults: int = None, NextToken: str = None
+        self, *, LedgerName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListJournalKinesisStreamsForLedgerResponseTypeDef:
         """
         Returns an array of all Amazon QLDB journal stream descriptors for a given
         ledger.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.list_journal_kinesis_streams_for_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.list_journal_kinesis_streams_for_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_journal_kinesis_streams_for_ledger)
         """
 
     def list_journal_s3_exports(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListJournalS3ExportsResponseTypeDef:
         """
         Returns an array of journal export job descriptions for all ledgers that are
         associated with the current account and Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_journal_s3_exports)
         """
 
     def list_journal_s3_exports_for_ledger(
-        self, *, Name: str, MaxResults: int = None, NextToken: str = None
+        self, *, Name: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListJournalS3ExportsForLedgerResponseTypeDef:
         """
         Returns an array of journal export job descriptions for a specified ledger.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports_for_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports_for_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_journal_s3_exports_for_ledger)
         """
 
     def list_ledgers(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListLedgersResponseTypeDef:
         """
         Returns an array of ledger summaries that are associated with the current
         account and Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.list_ledgers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.list_ledgers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_ledgers)
         """
 
@@ -264,7 +264,7 @@ class QLDBClient(BaseClient):
         """
         Returns all tags for a specified Amazon QLDB resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_tags_for_resource)
         """
 
@@ -276,13 +276,13 @@ class QLDBClient(BaseClient):
         InclusiveStartTime: Union[datetime, str],
         KinesisConfiguration: "KinesisConfigurationTypeDef",
         StreamName: str,
-        Tags: Mapping[str, str] = None,
-        ExclusiveEndTime: Union[datetime, str] = None
+        Tags: Mapping[str, str] = ...,
+        ExclusiveEndTime: Union[datetime, str] = ...
     ) -> StreamJournalToKinesisResponseTypeDef:
         """
         Creates a journal stream for a given Amazon QLDB ledger.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.stream_journal_to_kinesis)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.stream_journal_to_kinesis)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#stream_journal_to_kinesis)
         """
 
@@ -290,7 +290,7 @@ class QLDBClient(BaseClient):
         """
         Adds one or more tags to a specified Amazon QLDB resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#tag_resource)
         """
 
@@ -298,17 +298,17 @@ class QLDBClient(BaseClient):
         """
         Removes one or more tags from a specified Amazon QLDB resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#untag_resource)
         """
 
     def update_ledger(
-        self, *, Name: str, DeletionProtection: bool = None, KmsKey: str = None
+        self, *, Name: str, DeletionProtection: bool = ..., KmsKey: str = ...
     ) -> UpdateLedgerResponseTypeDef:
         """
         Updates properties on a ledger.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.update_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.update_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#update_ledger)
         """
 
@@ -318,6 +318,6 @@ class QLDBClient(BaseClient):
         """
         Updates the permissions mode of a ledger.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/qldb.html#QLDB.Client.update_ledger_permissions_mode)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/qldb.html#QLDB.Client.update_ledger_permissions_mode)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#update_ledger_permissions_mode)
         """
